@@ -354,11 +354,15 @@ const DocCommon = new Lang.Class({
         }
     },
 
-    canShare: function(callback) {
+    canEdit: function() {
+        log('Error: DocCommon implementations must override canEdit');
+    },
+
+    canShare: function() {
         log('Error: DocCommon implementations must override canShare');
     },
 
-    canTrash: function(callback) {
+    canTrash: function() {
         log('Error: DocCommon implementations must override canTrash');
     },
 
@@ -686,6 +690,10 @@ const LocalDocument = new Lang.Class({
             }));
     },
 
+    canEdit: function() {
+        return false;
+    },
+
     canShare: function() {
         return false;
     },
@@ -853,6 +861,10 @@ const GoogleDocument = new Lang.Class({
         this.parent(cursor);
     },
 
+    canEdit: function() {
+        return true;
+    },
+
     canShare: function() {
         return true;
     },
@@ -913,6 +925,10 @@ const OwncloudDocument = new Lang.Class({
             }));
     },
 
+    canEdit: function() {
+        return false;
+    },
+
     canShare: function() {
         return false;
     },
@@ -932,8 +948,8 @@ const SkydriveDocument = new Lang.Class({
         this.parent(cursor);
 
         // overridden
-        this.defaultAppName = _("Skydrive");
-        this.sourceName = _("Skydrive");
+        this.defaultAppName = _("OneDrive");
+        this.sourceName = _("OneDrive");
     },
 
     _createZpjEntry: function(cancellable, callback) {
@@ -1009,6 +1025,10 @@ const SkydriveDocument = new Lang.Class({
         this.typeDescription = description;
     },
 
+    canEdit: function() {
+        return false;
+    },
+
     canShare: function() {
         return false;
     },
