@@ -211,6 +211,10 @@ const Embed = new Lang.Class({
         this.widget = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                     visible: true });
 
+        let toplevel = Application.application.get_windows()[0];
+        this._titlebar = new Gtk.Grid({ visible: true });
+        toplevel.set_titlebar(this._titlebar);
+
         // create the toolbar for selected items, it's hidden by default
         this._selectionToolbar = new Selections.SelectionToolbar();
         this.widget.pack_end(this._selectionToolbar.widget, false, false, 0);
@@ -277,11 +281,9 @@ const Embed = new Lang.Class({
     },
 
     _onActivateResult: function() {
-        let iter = this._view.model.model.get_iter_first()[1];
-        if (iter) {
-            let id = this._view.model.model.get_value(iter, Gd.MainColumns.ID);
-            Application.documentManager.setActiveItem(Application.documentManager.getItemById(id))
-        };
+        let doc = this._view.getFirstDocument();
+        if (doc)
+            Application.documentManager.setActiveItem(doc)
     },
 
     _onQueryStatusChanged: function() {
@@ -358,8 +360,11 @@ const Embed = new Lang.Class({
             throw(new Error('Not handled'));
             break;
         }
-        this._toolbar.searchbar.connect('activate-result',
-                                        Lang.bind(this, this._onActivateResult));
+
+        if (this._toolbar.searchbar) {
+            this._toolbar.searchbar.connect('activate-result',
+                                            Lang.bind(this, this._onActivateResult));
+        }
     },
 
     _onActiveItemChanged: function(manager, doc) {
@@ -436,8 +441,7 @@ const Embed = new Lang.Class({
 
         // pack the toolbar
         this._toolbar = new MainToolbar.OverviewToolbar(this._stackOverlay);
-        let toplevel = Application.application.get_windows()[0];
-        toplevel.set_titlebar(this._toolbar.widget);
+        this._titlebar.add(this._toolbar.widget);
 
         this._spinnerBox.stop();
         this._stack.set_visible_child_name('view');
@@ -451,8 +455,7 @@ const Embed = new Lang.Class({
 
         // pack the toolbar
         this._toolbar = new Preview.PreviewToolbar(this._preview);
-        let toplevel = Application.application.get_windows()[0];
-        toplevel.set_titlebar(this._toolbar.widget);
+        this._titlebar.add(this._toolbar.widget);
     },
 
     _prepareForEdit: function() {
@@ -463,8 +466,7 @@ const Embed = new Lang.Class({
 
         // pack the toolbar
         this._toolbar = new Edit.EditToolbar(this._preview);
-        let toplevel = Application.application.get_windows()[0];
-        toplevel.set_titlebar(this._toolbar.widget);
+        this._titlebar.add(this._toolbar.widget);
 
         this._stack.set_visible_child_name('edit');
     },
